(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     22231,        673]
NotebookOptionsPosition[     20388,        609]
NotebookOutlinePosition[     20733,        624]
CellTagsIndexPosition[     20690,        621]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "UPGMA"
}], "Subtitle",
 CellChangeTimes->{3.670321495640956*^9, 3.670402706588908*^9, 
  3.6704272900450015`*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "Im Verlauf dieses Kapitels haben wir eine weit \[UDoubleDot]ber die \
Bioinformatik im engeren Sinne hinausreichende Analysemethode kennengelernt, \
n\[ADoubleDot]mlich die \[CapitalUDoubleDot]bersetzung paarweiser \
\[CapitalADoubleDot]hnlichkeiten von Elementen in einen Clusterbaum. In der \
Bioinformatik findet man solche Clusteralgorithmen vor allem bei einer \
Interpretation von Sequenz\[ADoubleDot]hnlichkeiten (oder auch allgemeiner: \
von Merkmals\[ADoubleDot]hnlichkeiten) in einem evolution\[ADoubleDot]ren \
Sinne. Clusteralgorithmen findet man aber auch bei der Analyse von \
Microarray-Daten, als rein statistisches Werkzeug zum Auffinden von \
Strukturen in numerischen Daten und \[Dash] wie wir in Kap. 5 sehen werden \
\[Dash] bei der Suche nach Modulen (also funktionell oder topologisch \
abgrenzbaren Untereinheiten) in biologischen Netzwerken. \n\nHier \
visualisieren wir beispielhaft ein Kernelement der UPGMA-Methode durch eine \
explizite, schrittweise Implementierung in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". Wir f\[UDoubleDot]hren aber auch vor, wie man schon vorgegebene Befehle \
zur Clusteranalyse in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " nutzen kann, um solche bioinformatischen Fragestellungen direkt zu \
untersuchen. \n\nWir beginnen mit der Distanzmatrix, die wir bereits im \
vorangegangenen Zahlenbeispiel kennengelernt haben."
}], "Text",
 CellChangeTimes->{{3.674638010827963*^9, 3.674638019576976*^9}, {
  3.6746381082351117`*^9, 3.674638155019181*^9}, {3.6775684443833885`*^9, 
  3.677568447628194*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"distMatrix", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1.3", ",", "0.75"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.3", ",", "0", ",", "0.34"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.75", ",", "0.34", ",", "0"}], "}"}]}], "}"}]}], 
  ";"}]], "Input"],

Cell[TextData[{
 "\[CapitalUDoubleDot]ber den Formatierungsbefehl ",
 StyleBox["MatrixForm",
  FontWeight->"Bold"],
 " k\[ODoubleDot]nnen wir die Distanzmatrix ausgeben:"
}], "Text",
 CellChangeTimes->{{3.6746381769752145`*^9, 3.6746381870442305`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"distMatrix", "//", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1.3`", "0.75`"},
     {"1.3`", "0", "0.34`"},
     {"0.75`", "0.34`", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.677571827448162*^9}]
}, Open  ]],

Cell[TextData[{
 "Gem\[ADoubleDot]\[SZ] der Interpretation als Distanzmatrix haben wir jetzt \
also eine sehr klare Aufgabe vor uns. Es liegen drei Taxa (z.B. Spezies, die \
wir mit unserer Analyse in einen evolution\[ADoubleDot]ren Zusammenhang \
stellen wollen) vor, zusammen mit ihren paarweisen Abst\[ADoubleDot]nden (in \
Bezug auf irgendeine Observable). \n\nZuerst m\[UDoubleDot]ssen wir die \
kleinste Distanz bestimmen. Unsere vom Alignment gewohnte Konstruktion ",
 StyleBox["Position[matrix, Min[matrix]]",
  FontWeight->"Bold"],
 " schl\[ADoubleDot]gt hier aufgrund der Nullen auf der Hauptdiagonalen fehl. \
Wir verwenden eine kleine Funktion ",
 StyleBox["makeDiag[n]",
  FontWeight->"Bold"],
 ", die eine Diagonalmatrix der Gr\[ODoubleDot]\[SZ]e ",
 StyleBox["n",
  FontSlant->"Italic"],
 "\[Times]",
 StyleBox["n",
  FontSlant->"Italic"],
 " mit einer gro\[SZ]en Zahl als Diagonalelemente (und Nullen sonst) erzeugt. \
Diese Matrix ",
 StyleBox["diag",
  FontWeight->"Bold"],
 " f\[UDoubleDot]gen wir als Zwischenschritt in die Minimumssuche ein. Man \
hat dann die Konstruktion ",
 StyleBox["Position[matrix + diag, Min[matrix + diag]]",
  FontWeight->"Bold"],
 ". Diese Position, zusammen mit dem Wert des Minimums, schreiben wir in die \
Variable ",
 StyleBox["merge1",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellChangeTimes->{{3.674638268654354*^9, 3.6746382881373825`*^9}, 
   3.6746383466054773`*^9, {3.6775480688545957`*^9, 3.677548074174205*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeDiag", "[", "n_", "]"}], ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"i", "\[Equal]", "j"}], ",", "100", ",", "0"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "n"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"diag", "=", 
  RowBox[{"makeDiag", "[", 
   RowBox[{"Length", "[", "distMatrix", "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"100", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "100", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "100"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.677571827510562*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"merge1", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Position", "[", 
      RowBox[{
       RowBox[{"distMatrix", "+", "diag"}], ",", 
       RowBox[{"Min", "[", 
        RowBox[{"distMatrix", "+", "diag"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"Min", "[", 
     RowBox[{"distMatrix", "+", "diag"}], "]"}]}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], ",", "0.34`"}], "}"}]], "Output",
 CellChangeTimes->{3.6775718275417624`*^9}]
}, Open  ]],

Cell[TextData[{
 "Dieses Wertepaar enth\[ADoubleDot]lt also die beiden Taxa 2 und 3 (erster \
Eintrag), zusammen mit ihrem Abstand (zweiter Eintrag). Wir fassen diese \
Arbeitsschritte in einer Funktion ",
 StyleBox["makeMerge",
  FontWeight->"Bold"],
 " zusammen."
}], "Text",
 CellChangeTimes->{{3.6746383704465137`*^9, 3.674638405351565*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"makeMerge", "[", "matr_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Position", "[", 
      RowBox[{
       RowBox[{"matr", "+", 
        RowBox[{"makeDiag", "[", 
         RowBox[{"Length", "[", "matr", "]"}], "]"}]}], ",", 
       RowBox[{"Min", "[", 
        RowBox[{"matr", "+", 
         RowBox[{"makeDiag", "[", 
          RowBox[{"Length", "[", "matr", "]"}], "]"}]}], "]"}]}], "]"}], "[", 
     
     RowBox[{"[", "1", "]"}], "]"}], ",", 
    RowBox[{"Min", "[", 
     RowBox[{"matr", "+", 
      RowBox[{"makeDiag", "[", 
       RowBox[{"Length", "[", "matr", "]"}], "]"}]}], "]"}]}], 
   "}"}]}]], "Input"],

Cell[TextData[{
 "Wie wir gesehen haben, werden im Verlaufe der Iteration Taxa zu gr\
\[ODoubleDot]\[SZ]eren Gruppen (Clustern) zusammengefasst. Es ist daher \
erforderlich, auch die aktuellen Cluster mitzuprotokollieren. Dies geschieht \
mit der Variablen ",
 StyleBox["clusterVec1",
  FontWeight->"Bold"],
 ". Zuerst initialisieren wir diese Variable."
}], "Text",
 CellChangeTimes->{{3.674638442724621*^9, 3.674638451048633*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"clusterVec1", "=", 
  RowBox[{"Table", "[", 
   RowBox[{"1", ",", 
    RowBox[{"{", 
     RowBox[{"Length", "[", "distMatrix", "]"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.677571827588562*^9}]
}, Open  ]],

Cell["\<\
Ein Update dieses Clustervektors ist sehr einfach. Wir schreiben die Summe \
der Eintr\[ADoubleDot]ge in die erste der beiden Koordinaten und l\
\[ODoubleDot]schen die zweite der beiden Koordinaten.\
\>", "Text",
 CellChangeTimes->{{3.6746384756656704`*^9, 3.6746384952607*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"modifyClusterVector", "[", 
   RowBox[{"clusters_", ",", "coord_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "tmp1", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmp1", "=", "clusters"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tmp1", "[", 
       RowBox[{"[", 
        RowBox[{"coord", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "=", 
      RowBox[{
       RowBox[{"tmp1", "[", 
        RowBox[{"[", 
         RowBox[{"coord", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "+", 
       RowBox[{"tmp1", "[", 
        RowBox[{"[", 
         RowBox[{"coord", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tmp1", "=", 
      RowBox[{"Drop", "[", 
       RowBox[{"tmp1", ",", 
        RowBox[{"{", 
         RowBox[{"coord", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", "tmp1"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"modifyClusterVector", "[", 
  RowBox[{"clusterVec1", ",", 
   RowBox[{"merge1", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{3.6775718276353617`*^9}]
}, Open  ]],

Cell[TextData[{
 "Als N\[ADoubleDot]chstes wollen wir den graduellen, durch Zusammenfassen \
von Taxa zu Clustern gesteuerten Abbau der Distanzmatrix implementieren, so \
wie wir ihn im Verlaufe dieses Kapitels kennengelernt haben. Die \
entsprechende Transformation der Distanzmatrix enth\[ADoubleDot]lt die \
zentrale Gleichung des UPGMA-Verfahrens, n\[ADoubleDot]mlich die \
Abstandsberechnung zwischen Clustern. Mit der (etwas unhandlichen, aber \
transparenten) Befehlskombination ",
 StyleBox["Transpose[Drop [Transpose[Drop[matrix, {number}]], {number}]]",
  FontWeight->"Bold"],
 " l\[ODoubleDot]schen wir zun\[ADoubleDot]chst ein Taxon (als Zeile und \
Spalte) aus der Matrix. Dann berechnen wir \[UDoubleDot]ber die \
Abstandsgleichung die neuen Abst\[ADoubleDot]nde, l\[ODoubleDot]schen auch \
dort das entsprechende Taxon und setzen diesen neuen Abstandsvektor in der \
Matrix anstelle des anderen zu entfernenden Taxons wieder ein."
}], "Text",
 CellChangeTimes->{{3.6746385094357214`*^9, 3.67463851576873*^9}, {
   3.674638569511811*^9, 3.674638594287848*^9}, 3.6775481983212233`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"computeNewMatrix", "[", 
   RowBox[{"matr_", ",", "clusters_", ",", "coord_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "tmp1", ",", "tmp2", ",", "tmp3", ",", "tmp4", ",", "tmp4b", ",", 
      "tmp5"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmp1", "=", 
      RowBox[{
       RowBox[{"Dimensions", "[", "matr", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tmp2", "=", 
      RowBox[{"Sort", "[", "coord", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"tmp3", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", 
          RowBox[{"Drop", "[", 
           RowBox[{"matr", ",", 
            RowBox[{"{", 
             RowBox[{"tmp2", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "}"}]}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"tmp2", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tmp4", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"matr", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"coord", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "k"}], "]"}], "]"}], "*", 
            RowBox[{"clusters", "[", 
             RowBox[{"[", 
              RowBox[{"coord", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"matr", "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"coord", "[", 
                RowBox[{"[", "2", "]"}], "]"}], ",", "k"}], "]"}], "]"}], "*", 
            RowBox[{"clusters", "[", 
             RowBox[{"[", 
              RowBox[{"coord", "[", 
               RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"clusters", "[", 
            RowBox[{"[", 
             RowBox[{"coord", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "+", 
           RowBox[{"clusters", "[", 
            RowBox[{"[", 
             RowBox[{"coord", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "tmp1"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tmp4b", "=", 
      RowBox[{"Insert", "[", 
       RowBox[{
        RowBox[{"Drop", "[", 
         RowBox[{
          RowBox[{"Drop", "[", 
           RowBox[{"tmp4", ",", 
            RowBox[{"{", 
             RowBox[{"tmp2", "[", 
              RowBox[{"[", "2", "]"}], "]"}], "}"}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"tmp2", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "}"}]}], "]"}], ",", "0.0", ",", 
        RowBox[{"tmp2", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tmp5", "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"tmp3", "/.", 
          RowBox[{
           RowBox[{"tmp3", "[", 
            RowBox[{"[", 
             RowBox[{"tmp2", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "\[Rule]", 
           "tmp4b"}]}], "]"}], "/.", 
        RowBox[{
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"tmp3", "/.", 
            RowBox[{
             RowBox[{"tmp3", "[", 
              RowBox[{"[", 
               RowBox[{"tmp2", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "\[Rule]", 
             "tmp4b"}]}], "]"}], "[", 
          RowBox[{"[", 
           RowBox[{"tmp2", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}], "\[Rule]", 
         "tmp4b"}]}], "]"}]}], ";", "\[IndentingNewLine]", "tmp5"}]}], 
   "]"}]}]], "Input"],

Cell[TextData[{
 "Diesen Befehl, der die neue, um ein Cluster reduzierte Matrix berechnet, k\
\[ODoubleDot]nnen wir nun auf die aktuellen Zust\[ADoubleDot]nde der \
Abstandsmatrix, des Clustervektors und der Variablen ",
 StyleBox["merge1",
  FontWeight->"Bold"],
 " anwenden:"
}], "Text",
 CellChangeTimes->{{3.674638614763878*^9, 3.6746386446159225`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"computeNewMatrix", "[", 
   RowBox[{"distMatrix", ",", "clusterVec1", ",", 
    RowBox[{"merge1", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "//", "MatrixForm"}]], "Input"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1.025`"},
     {"1.025`", "0.`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6775718276821623`*^9}]
}, Open  ]],

Cell[TextData[{
 "Diesen Schritt zu einer reduzierten Distanzmatrix kann man f\[UDoubleDot]r \
gr\[ODoubleDot]\[SZ]ere Ausgangsmatrizen iterieren. Die zusammengefassten \
Variablen ",
 StyleBox["merge1",
  FontWeight->"Bold"],
 " aus jedem Iterationsschritt entsprechen im Wesentlichen der Newick-Repr\
\[ADoubleDot]sentation eines solchen Baums. Die Anwendung der Befehle ",
 StyleBox["DirectAgglomerate",
  FontWeight->"Bold"],
 " und ",
 StyleBox["DendrogramPlot",
  FontWeight->"Bold"],
 " f\[UDoubleDot]hrt dann auf den Baum aus Abb. 3.30."
}], "Text",
 CellChangeTimes->{{3.6746386692839594`*^9, 3.6746387165710297`*^9}, 
   3.6761965536101456`*^9}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<HierarchicalClustering`\>\"", "]"}]], "Input",
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x", "=", 
  RowBox[{"DirectAgglomerate", "[", 
   RowBox[{"distMatrix", ",", 
    RowBox[{"Linkage", "\[Rule]", "\"\<Average\>\""}]}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.5777865773086114`*^9, {3.5777875252887373`*^9, 3.577787525632492*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"DirectAgglomerate", "::", "ties"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\[NoBreak] ties \
have been detected; reordering input may produce a different result. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, \
ButtonData:>\\\"paclet:HierarchicalClustering/ref/DirectAgglomerate\\\", \
ButtonNote -> \
\\\"HierarchicalClustering`DirectAgglomerate::ties\\\"]\\)\"\>"}]], "Message",\
 "MSG",
 CellChangeTimes->{3.677571828618164*^9}],

Cell[BoxData[
 RowBox[{"Cluster", "[", 
  RowBox[{"1", ",", 
   RowBox[{"Cluster", "[", 
    RowBox[{"2", ",", "3", ",", "0.34`", ",", "1", ",", "1"}], "]"}], ",", 
   "1.025`", ",", "1", ",", "2"}], "]"}]], "Output",
 CellChangeTimes->{3.677571828633764*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DendrogramPlot", "[", 
  RowBox[{"x", ",", 
   RowBox[{"LeafLabels", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"#", "&"}], ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{3.5777875391482897`*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[
    0, 1, 0]}, {{}, {LineBox[{{2, 0}, {2, 0.34}, {3, 0.34}, {3, 0}}], 
     LineBox[{{1, 0}, {1, 1.025}, {2.5, 1.025}, {2.5, 0.34}}]}}, {
    InsetBox["1", Offset[{0, -4}, {1, 0}], {0, 1}], 
    InsetBox["2", Offset[{0, -4}, {2, 0}], {0, 1}], 
    InsetBox["3", Offset[{0, -4}, {3, 0}], {0, 1}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  PlotRange->All]], "Output",
 CellChangeTimes->{3.677571828789764*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{507, 900},
WindowMargins->{{619, Automatic}, {Automatic, 267}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 870, 36, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1452, 60, 281, 9, 66, "Subtitle"],
Cell[1736, 71, 1599, 27, 467, "Text"],
Cell[3338, 100, 343, 11, 52, "Input"],
Cell[3684, 113, 252, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[3961, 123, 68, 1, 31, "Input"],
Cell[4032, 126, 681, 19, 71, "Output"]
}, Open  ]],
Cell[4728, 148, 1472, 34, 353, "Text"],
Cell[6203, 184, 377, 11, 52, "Input"],
Cell[CellGroupData[{
Cell[6605, 199, 130, 3, 31, "Input"],
Cell[6738, 204, 308, 9, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7083, 218, 408, 12, 92, "Input"],
Cell[7494, 232, 170, 5, 31, "Output"]
}, Open  ]],
Cell[7679, 240, 345, 8, 87, "Text"],
Cell[8027, 250, 677, 21, 92, "Input"],
Cell[8707, 273, 432, 9, 106, "Text"],
Cell[CellGroupData[{
Cell[9164, 286, 185, 5, 31, "Input"],
Cell[9352, 293, 125, 3, 31, "Output"]
}, Open  ]],
Cell[9492, 299, 288, 5, 68, "Text"],
Cell[9783, 306, 1054, 30, 152, "Input"],
Cell[CellGroupData[{
Cell[10862, 340, 164, 4, 31, "Input"],
Cell[11029, 346, 117, 3, 31, "Output"]
}, Open  ]],
Cell[11161, 352, 1098, 17, 296, "Text"],
Cell[12262, 371, 4030, 111, 512, "Input"],
Cell[16295, 484, 357, 8, 87, "Text"],
Cell[CellGroupData[{
Cell[16677, 496, 216, 5, 52, "Input"],
Cell[16896, 503, 641, 18, 56, "Output"]
}, Open  ]],
Cell[17552, 524, 655, 16, 125, "Text"],
Cell[18210, 542, 152, 3, 47, "Input"],
Cell[CellGroupData[{
Cell[18387, 549, 336, 8, 68, "Input"],
Cell[18726, 559, 576, 13, 39, "Message"],
Cell[19305, 574, 259, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19601, 585, 283, 8, 47, "Input"],
Cell[19887, 595, 473, 10, 273, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

